@@ -7,7 +7,7 @@ from Components.ActionMap import NumberActionMap
 from Components.Label import Label
 from Components.config import config, ConfigSubsection, ConfigSelection, ConfigSubList, KEY_LEFT, KEY_RIGHT, KEY_0, ConfigNothing, ConfigPIN, ConfigYesNo, NoSave
 from Components.ConfigList import ConfigList, ConfigListScreen
-from Components.SystemInfo import SystemInfo
+from Components.SystemInfo import BoxInfo
 from enigma import eTimer, eDVBCI_UI
 from os import remove
 from os.path import exists
@@ -17,7 +17,7 @@ forceNotShowCiMessages = False
 
 
 def setCIBitrate(configElement):
-	open(SystemInfo["CI%dSupportsHighBitrates" % configElement.slotid], "w").write(configElement.value)
+	open(BoxInfo.getItem("CI%dSupportsHighBitrates" % configElement.slotid), "w").write(configElement.value)
 
 
 def setCIEnabled(configElement):
@@ -25,18 +25,18 @@ def setCIEnabled(configElement):
 
 
 def setdvbCiDelay(configElement):
-	open(SystemInfo["CommonInterfaceCIDelay"], "w").write(configElement.value)
+	open(BoxInfo.getItem("CommonInterfaceCIDelay"), "w").write(configElement.value)
 
 
 def setRelevantPidsRouting(configElement):
-	open(SystemInfo["CI%dRelevantPidsRoutingSupport" % configElement.slotid], "w").write("yes" if configElement.value else "no")
+	open(BoxInfo.getItem("CI%dRelevantPidsRoutingSupport" % configElement.slotid), "w").write("yes" if configElement.value else "no")
 
 
 def InitCiConfig():
 	config.ci = ConfigSubList()
 	config.cimisc = ConfigSubsection()
-	if SystemInfo["CommonInterface"]:
-		for slot in range(SystemInfo["CommonInterface"]):
+	if BoxInfo.getItem("CommonInterface"):
+		for slot in range(BoxInfo.getItem("CommonInterface")):
 			config.ci.append(ConfigSubsection())
 			config.ci[slot].enabled = ConfigYesNo(default=True)
 			config.ci[slot].enabled.slotid = slot
@@ -45,7 +45,8 @@ def InitCiConfig():
 			config.ci[slot].use_static_pin = ConfigYesNo(default=True)
 			config.ci[slot].static_pin = ConfigPIN(default=0)
 			config.ci[slot].show_ci_messages = ConfigYesNo(default=True)
-			if SystemInfo["CI%dSupportsHighBitrates" % slot]:
+			config.ci[slot].supress_error10_message = ConfigYesNo(default=False)
+			if BoxInfo.getItem("CI%dSupportsHighBitrates" % slot):
 				highBitrateChoices = [("normal", _("normal")), ("high", _("high"))]
 				if exists("/proc/stb/tsmux/ci%d_tsclk_choices" % slot):
 					with open("/proc/stb/tsmux/ci%d_tsclk_choices" % slot) as fd:
@@ -55,11 +56,11 @@ def InitCiConfig():
 				config.ci[slot].highBitrate = ConfigSelection(default="high", choices=highBitrateChoices)
 				config.ci[slot].highBitrate.slotid = slot
 				config.ci[slot].highBitrate.addNotifier(setCIBitrate)
-			if SystemInfo["CI%dRelevantPidsRoutingSupport" % slot]:
+			if BoxInfo.getItem("CI%dRelevantPidsRoutingSupport" % slot):
 				config.ci[slot].relevantPidsRouting = ConfigYesNo(default=False)
 				config.ci[slot].relevantPidsRouting.slotid = slot
 				config.ci[slot].relevantPidsRouting.addNotifier(setRelevantPidsRouting)
-		if SystemInfo["CommonInterfaceCIDelay"]:
+		if BoxInfo.getItem("CommonInterfaceCIDelay"):
 			config.cimisc.dvbCiDelay = ConfigSelection(default="256", choices=[("16", "16"), ("32", "32"), ("64", "64"), ("128", "128"), ("256", "256")])
 			config.cimisc.dvbCiDelay.addNotifier(setdvbCiDelay)
 		bootDelayChoices = [(0, _("No timeout"))]
@@ -74,6 +75,8 @@ class MMIDialog(Screen):
 
 		print("MMIDialog with action" + str(action))
 
+		self["key_menu"] = StaticText(_("MENU"))
+		
 		self.mmiclosed = False
 		self.tag = None
 		self.slotid = slotid
@@ -328,6 +331,7 @@ class CiMessageHandler:
 		self.auto_close = False
 		self.ci = {}
 		self.dlgs = {}
+		self.err10supressed = False
 		eDVBCI_UI.getInstance().ciStateChanged.get().append(self.ciStateChanged)
 
 	def setSession(self, session):
@@ -346,6 +350,11 @@ class CiMessageHandler:
 					if config.ci[slot].show_ci_messages.value:
 						show_ui = True
 					screen_data = handler.getMMIScreen(slot)
+					if handler.isError10(slot) and config.ci[slot].supress_error10_message.value:
+						if not self.err10supressed:
+							self.err10supressed = True
+							handler.answerMenu(slot, 0)
+						show_ui = False
 					if config.ci[slot].use_static_pin.value:
 						if screen_data is not None and len(screen_data):
 							ci_tag = screen_data[0][0]
@@ -402,7 +411,7 @@ class CiSelection(Screen):
 		self.state = {}
 		self.list = []
 		self.slot = 0
-		for slot in range(SystemInfo["CommonInterface"]):
+		for slot in range(BoxInfo.getItem("CommonInterface")):
 			state = eDVBCI_UI.getInstance().getState(slot)
 			if state != -1:
 				self.slot += 1
@@ -466,19 +475,20 @@ class CiSelection(Screen):
 		self.list.append((_("Enter persistent PIN code"), ConfigNothing(), 5, slot))
 		self.list.append((_("Reset persistent PIN code"), ConfigNothing(), 6, slot))
 		self.list.append((_("Show CI messages"), config.ci[slot].show_ci_messages, 3, slot))
+		self.list.append((_("Hide and confirm invalid key message"), config.ci[slot].supress_error10_message, 3, slot))
 		self.list.append((_("Multiple service support"), config.ci[slot].canDescrambleMultipleServices, 3, slot))
-		if SystemInfo["CI%dSupportsHighBitrates" % slot]:
+		if BoxInfo.getItem("CI%dSupportsHighBitrates" % slot):
 			self.list.append((_("High bitrate support"), config.ci[slot].highBitrate, 3, slot))
-		if SystemInfo["CI%dRelevantPidsRoutingSupport" % slot]:
+		if BoxInfo.getItem("CI%dRelevantPidsRoutingSupport" % slot):
 			self.list.append((_("PID Filtering"), config.ci[slot].relevantPidsRouting, 3, slot))
-		if SystemInfo["CommonInterfaceCIDelay"]:
+		if BoxInfo.getItem("CommonInterfaceCIDelay"):
 			self.list.append((_("DVB CI Delay"), config.cimisc.dvbCiDelay, 3, slot))
 		self.list.append((_("CI Boot Delay"), config.cimisc.bootDelay, 3, slot))
 
 	def updateState(self, slot):
 		self.list = []
 		self.slot = 0
-		for module in range(SystemInfo["CommonInterface"]):
+		for module in range(BoxInfo.getItem("CommonInterface")):
 			state = eDVBCI_UI.getInstance().getState(module)
 			if state != -1:
 				self.slot += 1
@@ -526,7 +536,7 @@ class CiSelection(Screen):
 		pass
 
 	def cancel(self):
-		for slot in range(SystemInfo["CommonInterface"]):
+		for slot in range(BoxInfo.getItem("CommonInterface")):
 			state = eDVBCI_UI.getInstance().getState(slot)
 			if state != -1:
 				CiHandler.unregisterCIMessageHandler(slot)
